/*
 * Copyright (c) 2017 ARM Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "timeout.h"
#include "platform_retarget_dev.h"
#include "cmsis.h"
#include "timer_cmsdk.h"

#define SEC_TO_MSEC_MULTIPLIER    1000U

static uint32_t convert_ms_to_tick(uint32_t ms)
{
    return (ms * (SystemCoreClock / SEC_TO_MSEC_MULTIPLIER));
}

void timeout_init(struct timeout_t *timeout, uint32_t delay)
{
    if (timeout->is_initialized == false) {
        uint32_t reload_value = convert_ms_to_tick(delay);
        timeout->dev = &CMSDK_TIMER0_DEV_S;
        cmsdk_timer_init(timeout->dev);
        cmsdk_timer_set_reload_value(timeout->dev, reload_value);
        cmsdk_timer_enable_interrupt(timeout->dev);
        cmsdk_timer_enable(timeout->dev);
        timeout->is_initialized = true;
    }
}

bool timeout_delay_is_elapsed(struct timeout_t *timeout)
{
    if (cmsdk_timer_is_interrupt_active(timeout->dev)) {
        cmsdk_timer_clear_interrupt(timeout->dev);
        cmsdk_timer_reset(timeout->dev);
        return 1;
    }

    return 0;
}

