/*
 * Copyright (c) 2017 ARM Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "common.h"
#include "timer.h"
#include "cmsis.h"

#define CPU_ID_UNIT_BASE  0x5001F000

enum arm_mhu_sse_200_cpu_id_t _get_cpu_name(void)
{
    volatile uint32_t* p_cpu_id = (volatile uint32_t*)CPU_ID_UNIT_BASE;

    return (enum arm_mhu_sse_200_cpu_id_t)*p_cpu_id;
}

void press_doorbell(uint32_t physical_ch)
{
    uint32_t status;

    if(_get_cpu_name() == ARM_MHU_CPU0) {
        /* Wait until previous message is processed */
        do {
            (void)arm_mhu_sse_200_status(&ARM_MHU0_DEV_S,
                                         ARM_MHU_CPU1,
                                         &status);
        }while(status & physical_ch);

        (void)arm_mhu_sse_200_set(&ARM_MHU0_DEV_S, ARM_MHU_CPU1, physical_ch);
    } else {
        /* Wait until previous message is processed */
        do {
            (void)arm_mhu_sse_200_status(&ARM_MHU0_DEV_S,
                                         ARM_MHU_CPU0,
                                         &status);
        }while(status & physical_ch);

        (void)arm_mhu_sse_200_set(&ARM_MHU0_DEV_S, ARM_MHU_CPU0, physical_ch);
    }
}

void blink_led(uint32_t pin, uint32_t times, uint32_t delay)
{
    for(uint32_t i = 1; i <= times || times == 0; i++){
        arm_gpio_write(&ARM_GPIO0_DEV_S, ARM_GPIO_ACCESS_PIN, pin, 1);
        sleep_ms(delay);
        arm_gpio_write(&ARM_GPIO0_DEV_S, ARM_GPIO_ACCESS_PIN, pin, 0);
        sleep_ms(delay);
    }
}
