/*
 * Copyright (c) 2017 ARM Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "cmsis.h"
#include "timer.h"
#include "platform_retarget.h"

struct gp_timer {
    volatile uint32_t gptrest;
    volatile uint32_t gptintm;
    volatile uint32_t gptintc;
    volatile uint32_t reserved;
    volatile uint32_t gptalarm0;
    volatile uint32_t gptalarm1;
    volatile uint32_t gptintr;
    volatile uint32_t gptcounter;
};

static inline struct gp_timer* get_timer_base(void)
{
    return ((struct gp_timer*) MUSCA_TIMER_S_BASE);
}

static inline void sleep(uint32_t delay_ticks)
{
    uint32_t end;
    uint32_t start;
    struct gp_timer* gptimer = get_timer_base();

    start = gptimer->gptcounter;
    end   = start + delay_ticks;

    if (end >= start) {
        while (gptimer->gptcounter >= start && gptimer->gptcounter < end) {};
    } else {
        while (gptimer->gptcounter >= start){};
        while (gptimer->gptcounter < end){};
    }
}

void sleep_ms(uint32_t msec)
{
    uint32_t delay_ticks = (msec * (RefClock / 1000UL));

    sleep(delay_ticks);
}

