/*
 * Copyright (c) 2017 ARM Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#if defined (__ARMCC_VERSION) && (__ARMCC_VERSION >= 6010050)
__asm("  .global __ARM_use_no_argv\n");
#endif

#include "cmsis.h"
#include "platform_retarget_dev.h"
#include "platform_retarget_pins.h"
#include "region_defs.h"

#include "timer.h"
#include "common.h"

static uint32_t doorbell_status;

void MHU0_IRQHandler(void)
{
    (void)arm_mhu_sse_200_status(&ARM_MHU0_DEV_S,
                                 ARM_MHU_CPU0,
                                 &doorbell_status);
    arm_mhu_sse_200_clear(&ARM_MHU0_DEV_S, ARM_MHU_CPU0, doorbell_status);
}

static void wakeup_cpu1()
{
    struct sysctrl_t *ptr = (struct sysctrl_t *)MUSCA_SYSTEM_CTRL_S_BASE;
    ptr->initsvtor1 = CORE1_CODE_START;
    ptr->cpuwait = 0;
}

/*
 * \brief Wakes up cpu1, then performs doorbell using mhu
 */
int main(void)
{
    uint32_t physical_ch = 1, pin = 2;

    arm_gpio_init(&ARM_GPIO0_DEV_S);
    arm_gpio_config(&ARM_GPIO0_DEV_S, ARM_GPIO_ACCESS_PIN, pin,
                          (ARM_GPIO_PIN_ENABLE | ARM_GPIO_OUTPUT));

    /* Enable MHU0 IRQ*/
    NVIC_EnableIRQ((IRQn_Type)MHU0_IRQn);

    wakeup_cpu1();

    /* Press CPU1 doorbell */
    press_doorbell(physical_ch);

    /* Wait till CPU0 door bell pressed from CPU1 */
    while(doorbell_status != physical_ch) {
        ;
    }

    /* Blink red led forever */
    blink_led(pin, 0, 500);
    return 0;
}
