/*
 * Copyright (c) 2017 ARM Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#if defined (__ARMCC_VERSION) && (__ARMCC_VERSION >= 6010050)
__asm("  .global __ARM_use_no_argv\n");
#endif

#include "cmsis.h"
#include "platform_retarget_dev.h"
#include "platform_retarget_pins.h"

#include "timer.h"
#include "common.h"

static uint32_t doorbell_status;

void MHU0_IRQHandler(void)
{
    (void)arm_mhu_sse_200_status(&ARM_MHU0_DEV_S,
                                 ARM_MHU_CPU1,
                                 &doorbell_status);
    arm_mhu_sse_200_clear(&ARM_MHU0_DEV_S, ARM_MHU_CPU1, doorbell_status);
}

int main(void)
{
    uint32_t pin = 3;
    arm_gpio_init(&ARM_GPIO0_DEV_S);
    arm_gpio_config(&ARM_GPIO0_DEV_S, ARM_GPIO_ACCESS_PIN, pin,
                          (ARM_GPIO_PIN_ENABLE | ARM_GPIO_OUTPUT));

    /* Enable MHU0 IRQ*/
    NVIC_EnableIRQ((IRQn_Type)MHU0_IRQn);

    while(1) {
        if(doorbell_status) { /* Wait till CPU1 doorbell pressed from CPU0 */
           /* Press CPU0 doorbell */
           press_doorbell(doorbell_status);
           break;
        }
    }

    /* Blink green led forever */
    blink_led(pin, 0, 500);
    return 0;
}
